@@ -1,7 +1,7 @@
 package Khonsu;
 use strict;
 use warnings;
-our $VERSION = '0.07';
+our $VERSION = '0.08';
 use PDF::API2;
 
 use Khonsu::File;
@@ -29,7 +29,7 @@ Khonsu - PDF Generation!
 
 =head1 VERSION
 
-Version 0.07
+Version 0.08
 
 =cut
 
@@ -110,6 +110,8 @@ Version 0.07
 
 	$khonsu->add_toc();
 
+	$khonsu->set_columns(2);
+
 	for (0 .. 100) {
 		$khonsu->add_h1(
 			text => $generate_text->(3),
@@ -123,6 +125,8 @@ Version 0.07
 		);
 	}
 
+	$khonsu->set_columns(1);
+
 	$khonsu->add_h1(
 		text => 'A simple form',
 		toc => 1
@@ -147,6 +151,10 @@ Version 0.07
 
 =cut
 
+=head2 set_columns
+
+=cut
+
 =head2 open_page
 
 =cut
