@@ -68,12 +68,20 @@ sub open_page {
 	return $self;
 }
 
+sub set_columns {
+	my ($self, $columns) = @_;
+	$self->page->columns($columns);
+	$self->page->column_y($self->page->y);
+	return $self;
+}
+
 sub add_page {
 	my ($self, %args) = @_;
 
 	my $page = $self->page(Khonsu::Page->new(
 		header => $self->page && $self->page->header ? $self->page->header->clone() : undef,
 		footer => $self->page && $self->page->footer ? $self->page->footer->clone() : undef,
+		columns => $self->page ? $self->page->columns : 1,
 		page_size =>'A4',
 		num => scalar @{$self->pages} + 1,
 		%{ $self->page_args },
