@@ -13,8 +13,7 @@ sub attributes {
 		current => {$a->RW, $a->OBJ},
 		columns => {$a->RW, $a->NUM, default => sub { 1 }},
 		column => {$a->RW, $a->NUM, default => sub { 1 }},
-		rows => {$a->RW, $a->NUM, default => sub { 1 }},
-		row => {$a->RW, $a->NUM, default => sub { 1 }},
+		column_y => {$a->RW, $a->NUM, default => sub {1 }},
 		is_rotated => {$a->RW, $a->NUM},
 		header => {$a->RW, $a->OBJ},
 		footer => {$a->RW, $a->OBJ},
@@ -43,8 +42,9 @@ sub add {
 	}
 
 	if ($self->header) {
-		$self->y($self->header->h);
+		$self->column_y($self->y($self->header->h));
 	}
+
 	if ($self->padding) {
 		$self->x($self->padding);
 	}
@@ -78,7 +78,19 @@ sub remaining_height {
 
 sub width {
 	my ($self) = @_;
-	return $self->w - ($self->padding * 2);
+	return ($self->w - ($self->padding * (2 + ($self->columns - 1)))) / $self->columns;
+}
+
+sub next {
+	my ($self, $file) = @_;
+	if ($self->column < $self->columns) {
+		$self->column($self->column + 1);
+		$self->x($self->x + $self->width + $self->padding);
+		$self->y($self->column_y);
+	} else {
+		$self->column(1);
+		$file->add_page();
+	}
 }
 
 1;
