@@ -99,7 +99,7 @@ sub add {
 	$file->page->y($file->page->h - (($ypos + $pos{l}) - $self->margin));
 
 	if (!$self->overflow && scalar @words) {
-		$file->add_page();
+		$file->page->next($file);
 		return $self->add($file, text => join " ", @words);
 	}
 
